==> opuscodium-firefox-4.1.0.tar.gz: opuscodium-firefox-4.1.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [4.1.0](https://github.com/opus-codium/puppet-firefox/tree/4.1.0) (2022-09-10)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/4.0.1...4.1.0)

**Implemented enhancements:**

- Add support for Windows 11 [\#45](https://github.com/opus-codium/puppet-firefox/pull/45) ([smortex](https://github.com/smortex))
- Add support for Debian 11 [\#42](https://github.com/opus-codium/puppet-firefox/pull/42) ([smortex](https://github.com/smortex))

**Merged pull requests:**

- Fix CI [\#44](https://github.com/opus-codium/puppet-firefox/pull/44) ([smortex](https://github.com/smortex))
- Allow stdlib 8.x [\#43](https://github.com/opus-codium/puppet-firefox/pull/43) ([smortex](https://github.com/smortex))

## [4.0.1](https://github.com/opus-codium/puppet-firefox/tree/4.0.1) (2021-05-14)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/4.0.0...4.0.1)

**Fixed bugs:**

- Fix CHANGELOG.md [\#40](https://github.com/opus-codium/puppet-firefox/pull/40) ([smortex](https://github.com/smortex))

## [4.0.0](https://github.com/opus-codium/puppet-firefox/tree/4.0.0) (2021-05-14)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/3.0.0...4.0.0)

**Breaking changes:**

- Remove Puppet 5 from testing and bump minimal version to 6.0.0 [\#38](https://github.com/opus-codium/puppet-firefox/pull/38) ([smortex](https://github.com/smortex))

**Implemented enhancements:**

- Update dependencies [\#37](https://github.com/opus-codium/puppet-firefox/pull/37) ([smortex](https://github.com/smortex))

## [3.0.0](https://github.com/opus-codium/puppet-firefox/tree/3.0.0) (2021-04-12)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/2.0.0...3.0.0)

**Breaking changes:**

- Rework the way we build the preferences filename [\#33](https://github.com/opus-codium/puppet-firefox/pull/33) ([smortex](https://github.com/smortex))

**Implemented enhancements:**

- Add support for FreeBSD 13 [\#36](https://github.com/opus-codium/puppet-firefox/pull/36) ([smortex](https://github.com/smortex))
- Add support for policies [\#34](https://github.com/opus-codium/puppet-firefox/pull/34) ([smortex](https://github.com/smortex))

## [2.0.0](https://github.com/opus-codium/puppet-firefox/tree/2.0.0) (2021-01-11)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/1.1.0...2.0.0)

**Implemented enhancements:**

- Add support for windows [\#26](https://github.com/opus-codium/puppet-firefox/pull/26) ([smortex](https://github.com/smortex))
- Add REFERENCE.md [\#25](https://github.com/opus-codium/puppet-firefox/pull/25) ([neomilium](https://github.com/neomilium))

## [1.1.0](https://github.com/opus-codium/puppet-firefox/tree/1.1.0) (2020-12-21)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/1.0.2...1.1.0)

**Implemented enhancements:**

- Add support for Ubuntu [\#18](https://github.com/opus-codium/puppet-firefox/pull/18) ([neomilium](https://github.com/neomilium))
- Add documentation [\#15](https://github.com/opus-codium/puppet-firefox/pull/15) ([smortex](https://github.com/smortex))
- Add support for KDE neon distribution [\#13](https://github.com/opus-codium/puppet-firefox/pull/13) ([neomilium](https://github.com/neomilium))

**Merged pull requests:**

- Support KDE neon 20.04 [\#21](https://github.com/opus-codium/puppet-firefox/pull/21) ([neomilium](https://github.com/neomilium))

## [1.0.2](https://github.com/opus-codium/puppet-firefox/tree/1.0.2) (2019-05-06)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/1.0.1...1.0.2)

## [1.0.1](https://github.com/opus-codium/puppet-firefox/tree/1.0.1) (2019-04-26)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/1.0.0...1.0.1)

## [1.0.0](https://github.com/opus-codium/puppet-firefox/tree/1.0.0) (2019-04-23)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/ba229a093dfe4bce58a415211867ea4adacea003...1.0.0)

**Implemented enhancements:**

- Add support for PureOS [\#11](https://github.com/opus-codium/puppet-firefox/pull/11) ([smortex](https://github.com/smortex))
- Allow to lock preferences [\#5](https://github.com/opus-codium/puppet-firefox/pull/5) ([smortex](https://github.com/smortex))
- Switch to Hiera 5 [\#4](https://github.com/opus-codium/puppet-firefox/pull/4) ([smortex](https://github.com/smortex))
- Ensure $firefox::config is a file name [\#3](https://github.com/opus-codium/puppet-firefox/pull/3) ([smortex](https://github.com/smortex))
- Test on all supported Ruby versions [\#2](https://github.com/opus-codium/puppet-firefox/pull/2) ([smortex](https://github.com/smortex))

**Fixed bugs:**

- Fix deprecation warning [\#10](https://github.com/opus-codium/puppet-firefox/pull/10) ([smortex](https://github.com/smortex))
- Manage firefox package [\#6](https://github.com/opus-codium/puppet-firefox/pull/6) ([smortex](https://github.com/smortex))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> opuscodium-firefox-5.0.0.tar.gz: opuscodium-firefox-5.0.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.
Each new release typically also includes the latest modulesync defaults.
These should not affect the functionality of the module.

## [v5.0.0](https://github.com/opus-codium/puppet-firefox/tree/v5.0.0) (2023-10-05)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/v4.2.0...v5.0.0)

**Breaking changes:**

- Drop Puppet 6 \(EOL\) [\#57](https://github.com/opus-codium/puppet-firefox/pull/57) ([smortex](https://github.com/smortex))
- Require puppetlabs/stdlib 9.x [\#52](https://github.com/opus-codium/puppet-firefox/pull/52) ([smortex](https://github.com/smortex))

**Implemented enhancements:**

- Add support for Puppet 8 [\#51](https://github.com/opus-codium/puppet-firefox/pull/51) ([smortex](https://github.com/smortex))

## [v4.2.0](https://github.com/opus-codium/puppet-firefox/tree/v4.2.0) (2023-06-15)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/v4.1.0...v4.2.0)

**Implemented enhancements:**

- Relax dependencie's version requirements [\#48](https://github.com/opus-codium/puppet-firefox/pull/48) ([smortex](https://github.com/smortex))

## [v4.1.0](https://github.com/opus-codium/puppet-firefox/tree/v4.1.0) (2022-09-12)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/4.0.1...v4.1.0)

**Implemented enhancements:**

- Add support for Windows 11 [\#45](https://github.com/opus-codium/puppet-firefox/pull/45) ([smortex](https://github.com/smortex))
- Add support for Debian 11 [\#42](https://github.com/opus-codium/puppet-firefox/pull/42) ([smortex](https://github.com/smortex))

**Merged pull requests:**

- Fix CI [\#44](https://github.com/opus-codium/puppet-firefox/pull/44) ([smortex](https://github.com/smortex))
- Allow stdlib 8.x [\#43](https://github.com/opus-codium/puppet-firefox/pull/43) ([smortex](https://github.com/smortex))

## [4.0.1](https://github.com/opus-codium/puppet-firefox/tree/4.0.1) (2021-05-14)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/4.0.0...4.0.1)

**Fixed bugs:**

- Fix CHANGELOG.md [\#40](https://github.com/opus-codium/puppet-firefox/pull/40) ([smortex](https://github.com/smortex))

## [4.0.0](https://github.com/opus-codium/puppet-firefox/tree/4.0.0) (2021-05-14)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/3.0.0...4.0.0)

**Breaking changes:**

- Remove Puppet 5 from testing and bump minimal version to 6.0.0 [\#38](https://github.com/opus-codium/puppet-firefox/pull/38) ([smortex](https://github.com/smortex))

**Implemented enhancements:**

- Update dependencies [\#37](https://github.com/opus-codium/puppet-firefox/pull/37) ([smortex](https://github.com/smortex))

## [3.0.0](https://github.com/opus-codium/puppet-firefox/tree/3.0.0) (2021-04-12)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/2.0.0...3.0.0)

**Breaking changes:**

- Rework the way we build the preferences filename [\#33](https://github.com/opus-codium/puppet-firefox/pull/33) ([smortex](https://github.com/smortex))

**Implemented enhancements:**

- Add support for FreeBSD 13 [\#36](https://github.com/opus-codium/puppet-firefox/pull/36) ([smortex](https://github.com/smortex))
- Add support for policies [\#34](https://github.com/opus-codium/puppet-firefox/pull/34) ([smortex](https://github.com/smortex))

## [2.0.0](https://github.com/opus-codium/puppet-firefox/tree/2.0.0) (2021-01-11)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/1.1.0...2.0.0)

**Implemented enhancements:**

- Add support for windows [\#26](https://github.com/opus-codium/puppet-firefox/pull/26) ([smortex](https://github.com/smortex))
- Add REFERENCE.md [\#25](https://github.com/opus-codium/puppet-firefox/pull/25) ([neomilium](https://github.com/neomilium))

## [1.1.0](https://github.com/opus-codium/puppet-firefox/tree/1.1.0) (2020-12-21)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/1.0.2...1.1.0)

**Implemented enhancements:**

- Add support for Ubuntu [\#18](https://github.com/opus-codium/puppet-firefox/pull/18) ([neomilium](https://github.com/neomilium))
- Add documentation [\#15](https://github.com/opus-codium/puppet-firefox/pull/15) ([smortex](https://github.com/smortex))
- Add support for KDE neon distribution [\#13](https://github.com/opus-codium/puppet-firefox/pull/13) ([neomilium](https://github.com/neomilium))

**Merged pull requests:**

- Support KDE neon 20.04 [\#21](https://github.com/opus-codium/puppet-firefox/pull/21) ([neomilium](https://github.com/neomilium))

## [1.0.2](https://github.com/opus-codium/puppet-firefox/tree/1.0.2) (2019-05-06)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/1.0.1...1.0.2)

## [1.0.1](https://github.com/opus-codium/puppet-firefox/tree/1.0.1) (2019-04-26)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/1.0.0...1.0.1)

## [1.0.0](https://github.com/opus-codium/puppet-firefox/tree/1.0.0) (2019-04-23)

[Full Changelog](https://github.com/opus-codium/puppet-firefox/compare/ba229a093dfe4bce58a415211867ea4adacea003...1.0.0)

**Implemented enhancements:**

- Add support for PureOS [\#11](https://github.com/opus-codium/puppet-firefox/pull/11) ([smortex](https://github.com/smortex))
- Allow to lock preferences [\#5](https://github.com/opus-codium/puppet-firefox/pull/5) ([smortex](https://github.com/smortex))
- Switch to Hiera 5 [\#4](https://github.com/opus-codium/puppet-firefox/pull/4) ([smortex](https://github.com/smortex))
- Ensure $firefox::config is a file name [\#3](https://github.com/opus-codium/puppet-firefox/pull/3) ([smortex](https://github.com/smortex))
- Test on all supported Ruby versions [\#2](https://github.com/opus-codium/puppet-firefox/pull/2) ([smortex](https://github.com/smortex))

**Fixed bugs:**

- Fix deprecation warning [\#10](https://github.com/opus-codium/puppet-firefox/pull/10) ([smortex](https://github.com/smortex))
- Manage firefox package [\#6](https://github.com/opus-codium/puppet-firefox/pull/6) ([smortex](https://github.com/smortex))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
